@@ -197,6 +197,24 @@ GSwitchItAppletFilterXEvt (GdkXEvent * xev,
 	XEvent *xevent = (XEvent *) xev;
 	Display *display = xevent->xany.display;
 	XklFilterEvents (xevent);
+	switch (xevent->type) {
+	case ReparentNotify:
+		{
+			XReparentEvent *rne = (XReparentEvent *) xev;
+			GtkWidget *w1;
+			GdkWindow *w;
+			w1 = gtk_widget_get_ancestor (sia->applet,
+						      GTK_TYPE_WINDOW);
+			if (w1 == NULL)
+				break;
+			w = w1->window;
+			if (w == NULL || GDK_WINDOW_XID (w) != rne->window)
+				break;
+			XklSetTransparent (GDK_WINDOW_XID (w), TRUE);
+		}
+		break;
+	}
+
 	return GDK_FILTER_CONTINUE;
 }
 
@@ -247,11 +265,12 @@ GSwitchItAppletPrepareDrawing (GSwitchItApplet * sia, int group)
 {
 	GdkPixbuf *image = sia->appletConfig.images[group];
 	GdkPixbuf *scaled;
-	GtkWidget *groupDrawingArea;
 	PanelAppletOrient orient;
 	int psize, xsize = 0, ysize = 0;
 	double xyratio;
+	sia->ebox = gtk_event_box_new ();
 	if (sia->appletConfig.showFlags) {
+		GtkWidget *flagImg;
 		if (image == NULL)
 			return NULL;
 		orient =
@@ -277,10 +296,13 @@ GSwitchItAppletPrepareDrawing (GSwitchItApplet * sia, int group)
 		scaled =
 		    gdk_pixbuf_scale_simple (image, xsize, ysize,
 					     GDK_INTERP_HYPER);
-		groupDrawingArea = gtk_image_new_from_pixbuf (scaled);
+		flagImg = gtk_image_new_from_pixbuf (scaled);
+		gtk_container_add (GTK_CONTAINER (sia->ebox), flagImg);
 		g_object_unref (G_OBJECT (scaled));
+		//sia->ebox = NULL;	// not used in this case!
 	} else {
 		char *layoutName;
+		char *allocLayoutName = NULL;
 		XklConfigItem configItem;
 		GtkWidget *align, *label;
 
@@ -300,31 +322,34 @@ GSwitchItAppletPrepareDrawing (GSwitchItApplet * sia, int group)
 
 			if (XklConfigFindLayout (&configItem)) {
 				char *sd = configItem.shortDescription;
-				if (sd != NULL && *sd != '\0')
-					layoutName = sd;
+				if (sd != NULL && *sd != '\0') {
+					layoutName = allocLayoutName =
+					    g_locale_to_utf8 (sd, -1, NULL,
+							      NULL, NULL);
+				}
 			}
 		} else
 			layoutName = sia->groupNames[group];
 		align = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
 		label = gtk_label_new (layoutName);
-		sia->ebox = gtk_event_box_new ();
-		groupDrawingArea = sia->ebox;
-		g_signal_connect (G_OBJECT (sia->ebox),
-				  "button_press_event",
-				  G_CALLBACK
-				  (GSwitchItAppletButtonPressed), sia);
-
-		g_signal_connect (G_OBJECT (sia->applet),
-				  "key_press_event",
-				  G_CALLBACK
-				  (GSwitchItAppletKeyPressed), sia);
-
+		if (allocLayoutName != NULL)
+			g_free (allocLayoutName);
 		gtk_container_add (GTK_CONTAINER (align), label);
 		gtk_container_add (GTK_CONTAINER (sia->ebox), align);
 
 		gtk_container_set_border_width (GTK_CONTAINER (align), 2);
 	}
-	return groupDrawingArea;
+	g_signal_connect (G_OBJECT (sia->ebox),
+			  "button_press_event",
+			  G_CALLBACK
+			  (GSwitchItAppletButtonPressed), sia);
+
+	g_signal_connect (G_OBJECT (sia->applet),
+			  "key_press_event",
+			  G_CALLBACK
+			  (GSwitchItAppletKeyPressed), sia);
+
+	return sia->ebox;
 }
 
 static void
@@ -386,31 +411,43 @@ GSwitchItAppletChangePixelSize (PanelApplet *
 static void
 GSwitchItAppletChangeBackground (PanelApplet *
 				 widget, PanelAppletBackgroundType type,
-				 GdkColor *color, GdkPixmap *pixmap,
+				 GdkColor * color, GdkPixmap * pixmap,
 				 GSwitchItApplet * sia)
 {
 	GtkRcStyle *rc_style = gtk_rc_style_new ();
 
 	switch (type) {
-		case PANEL_PIXMAP_BACKGROUND:
-			gtk_widget_modify_style (GTK_WIDGET (sia->ebox), rc_style);
-			gtk_widget_modify_style (GTK_WIDGET (sia->applet), rc_style);
-			break;
+	case PANEL_PIXMAP_BACKGROUND:
+		if (sia->ebox != NULL)
+			gtk_widget_modify_style (GTK_WIDGET (sia->ebox),
+						 rc_style);
+		gtk_widget_modify_style (GTK_WIDGET (sia->applet),
+					 rc_style);
+		break;
 
-		case PANEL_COLOR_BACKGROUND:
-			gtk_widget_modify_bg (GTK_WIDGET (sia->ebox), GTK_STATE_NORMAL, color);
-			gtk_widget_modify_bg (GTK_WIDGET (sia->applet), GTK_STATE_NORMAL, color);
-			break;
+	case PANEL_COLOR_BACKGROUND:
+		if (sia->ebox != NULL)
+			gtk_widget_modify_bg (GTK_WIDGET (sia->ebox),
+					      GTK_STATE_NORMAL, color);
+		gtk_widget_modify_bg (GTK_WIDGET (sia->applet),
+				      GTK_STATE_NORMAL, color);
+		break;
 
-		case PANEL_NO_BACKGROUND:
-			gtk_widget_modify_style (GTK_WIDGET (sia->ebox), rc_style);
-			gtk_widget_modify_style (GTK_WIDGET (sia->applet), rc_style);
-			break;
+	case PANEL_NO_BACKGROUND:
+		if (sia->ebox != NULL)
+			gtk_widget_modify_style (GTK_WIDGET (sia->ebox),
+						 rc_style);
+		gtk_widget_modify_style (GTK_WIDGET (sia->applet),
+					 rc_style);
+		break;
 
-		default:
-			gtk_widget_modify_style (GTK_WIDGET (sia->ebox), rc_style);
-			gtk_widget_modify_style (GTK_WIDGET (sia->applet), rc_style);
-			break;
+	default:
+		if (sia->ebox != NULL)
+			gtk_widget_modify_style (GTK_WIDGET (sia->ebox),
+						 rc_style);
+		gtk_widget_modify_style (GTK_WIDGET (sia->applet),
+					 rc_style);
+		break;
 	}
 
 	gtk_rc_style_unref (rc_style);
@@ -444,6 +481,7 @@ GSwitchItAppletButtonPressed (GtkWidget *
 			      event, GSwitchItAppletConfig * config)
 {
 	if (event->button == 1 && event->type == GDK_BUTTON_PRESS) {
+		XklDebug (150, "Mouse button pressed on applet\n");
 		GSwitchItAppletConfigLockNextGroup ();
 		return TRUE;
 	}
@@ -575,7 +613,7 @@ GSwitchItAppletCmdAbout (BonoboUIComponent *
 	    gnome_about_new (_("Keyboard Indicator"), VERSION,
 /* Translators: Please replace (C) with the proper copyright character. */
 			     _
-			     ("Copyright (c) Sergey V. Oudaltsov 1999-2004"),
+			     ("Copyright (c) Sergey V. Udaltsov 1999-2004"),
 			     _
 			     ("Keyboard layout indicator applet for GNOME"),
 			     authors, documenters, translatorCredits,
@@ -783,7 +821,7 @@ GSwitchItAppletInit (GSwitchItApplet * sia, PanelApplet * applet)
 	g_signal_connect (G_OBJECT (sia->applet), "change_background",
 			  G_CALLBACK (GSwitchItAppletChangeBackground),
 			  sia);
-	
+
 	GSwitchItAppletStartListen (sia);
 	gtk_widget_add_events (sia->applet, GDK_BUTTON_PRESS_MASK);
 
@@ -835,7 +873,6 @@ GSwitchItAppletNew (PanelApplet * applet)
 	fatal_mask = G_LOG_LEVEL_WARNING | G_LOG_LEVEL_CRITICAL;
 	g_log_set_always_fatal (fatal_mask);
 #endif
-	/* BASTARDS! THEY CALL THIS METHOD TWICE!!! */
 	if (theAppletInstance == NULL) {
 		terminatedOnce = FALSE;
 		theAppletInstance = g_new0 (GSwitchItApplet, 1);
