@@ -25,12 +25,11 @@
 #include <libgnomeui/libgnomeui.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h> 
-#include <egg-screen-help.h>
 #include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 #include <time.h>
 
-#include <libgnome/gnome-help.h>
+#include <libgnomeui/gnome-help.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -41,6 +40,8 @@
 
 #define STOCK_QUOTE(sq) ((StockQuote *)(sq))
 
+#define MAX_SYMBOL_LEN 1024
+
 #define NEVER_SENSITIVE		"never_sensitive"
 
 	enum {
@@ -164,6 +165,7 @@
 	GtkWidget *access_drawing_area;
 	StockData *access_stock;
 
+	extern void set_relation (GtkWidget *widget, GtkLabel *label);
 	static void setup_refchild_nchildren(GtkWidget * vbox);
 	static gint gtik_vbox_accessible_get_n_children(AtkObject *obj);
 	static AtkObject* gtik_vbox_accessible_ref_child(AtkObject *obj, gint i);
@@ -274,6 +276,10 @@ static gint updateOutput(gpointer data)
 		stockdata->vfshandle = NULL;
 	}
 
+	if (stockdata->props.tik_syms == NULL) {
+		setOutputArray (stockdata, _("No stock list"));
+		return TRUE;
+	}
         /*
          * Now using a CSV file to get quotes. Specification of CSV format
          * is in URL f=sl1c1.
@@ -425,7 +431,7 @@ static gint updateOutput(gpointer data)
 
 
 	/*-----------------------------------------------------------------*/
-	static char *parseQuote(char line[1024]) {
+	static char *parseQuote(char line[MAX_SYMBOL_LEN]) {
 		
                 char *symbol;
                 char *price;
@@ -474,7 +480,7 @@ static gint updateOutput(gpointer data)
 	int configured(StockData *stockdata) {
 		int retVar;
 
-		char  buffer[1024];
+		char  buffer[MAX_SYMBOL_LEN];
 		static FILE *CONFIG;
 
 		CONFIG = fopen((const char *)stockdata->configFileName,"r");
@@ -768,7 +774,7 @@ static gint updateOutput(gpointer data)
 			     StockData         *stockdata, 
 			     const char        *verbname) 
 	{
-		egg_help_display_on_screen (
+		gnome_help_display_on_screen (
 				"gtik2_applet2", NULL,
 				gtk_widget_get_screen (stockdata->applet),
 				NULL);
@@ -969,24 +975,49 @@ static gint updateOutput(gpointer data)
 		GtkTreeModel *model;
 		GtkTreeIter row;
 		gchar *symbol;
+		gchar *temp_symbol;
+		gchar *full_symbol;
 		gchar *tmp;
+		gint symbol_len;
+		gint i, j=0;
+		gboolean flag = FALSE;
 		
 		symbol = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+		symbol_len = strlen (symbol);
+
+		full_symbol = (char *) malloc ((symbol_len + 1) * sizeof (char));
 		if (!symbol)
 			return;
-		
-		g_strstrip (symbol);
-		
+
 		if (strlen (symbol) < 1) {
 			g_free (symbol);
 			return;
 		}
 		
+		for (i=0; i<symbol_len; i++) {
+			if (symbol[i] == ' ' || symbol[i] == ',') {
+				if (flag) {
+					full_symbol[j]='+';
+					j++;
+					flag = FALSE;
+				}
+				else 
+					continue;
+			}
+			else {
+				full_symbol[j] = symbol[i];
+				j++;
+				flag = TRUE;
+			}
+		}
+
+		full_symbol[j]= '\0';
+		
 		tmp = stockdata->props.tik_syms;
 		if (tmp)
-			stockdata->props.tik_syms = g_strconcat (tmp, "+", symbol, NULL);
+			stockdata->props.tik_syms = g_strconcat (tmp, "+", full_symbol, NULL);
 		else
-			stockdata->props.tik_syms = g_strdup (symbol);
+			stockdata->props.tik_syms = g_strdup (full_symbol);
 		
 		panel_applet_gconf_set_string (applet, "tik_syms", 
 					       stockdata->props.tik_syms, NULL);
@@ -996,12 +1027,18 @@ static gint updateOutput(gpointer data)
 		
 		list = g_object_get_data (G_OBJECT (entry), "list");
 		model = gtk_tree_view_get_model (GTK_TREE_VIEW (list));
-		gtk_list_store_append (GTK_LIST_STORE (model), &row);
-		gtk_list_store_set (GTK_LIST_STORE (model), &row, 
-					    0, symbol, -1);
+
+		temp_symbol = strtok (full_symbol, "+");
+		for (; temp_symbol;) {
+			gtk_list_store_append (GTK_LIST_STORE (model), &row);
+			gtk_list_store_set (GTK_LIST_STORE (model), &row, 
+					    0, temp_symbol, -1);
+			temp_symbol = strtok (NULL, "+");
+		}
 					    
 		gtk_entry_set_text (entry, "");
 		g_free (symbol);
+		g_free (full_symbol);
 		updateOutput(stockdata);
 		
 	}
@@ -1217,6 +1254,7 @@ static gint updateOutput(gpointer data)
 		stockdata->tik_syms_entry = list;
 		
 		swindow = gtk_scrolled_window_new(NULL,NULL);
+		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (swindow), GTK_SHADOW_IN);
 		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(swindow),
 						GTK_POLICY_AUTOMATIC,
 						GTK_POLICY_AUTOMATIC);
@@ -1280,7 +1318,7 @@ static gint updateOutput(gpointer data)
 	{
   		GError *error = NULL;
 
-  		egg_help_display_on_screen (
+  		gnome_help_display_on_screen (
 			"gtik2_applet2", "gtik-settings",
 			gtk_window_get_screen (GTK_WINDOW (dialog)),
 			&error);
@@ -1687,7 +1725,7 @@ static gint updateOutput(gpointer data)
     	{
     		StockData *stockdata = data;
     		
-    		if (stockdata->props.use_default_theme);
+    		if (stockdata->props.use_default_theme)
     			load_fonts (stockdata);
     	}
 
@@ -1753,10 +1791,10 @@ static gint updateOutput(gpointer data)
 				   right_arrow);
 		gtk_widget_show_all (stockdata->leftButton);
 		gtk_widget_show_all (stockdata->rightButton);				
-		gtk_signal_connect (GTK_OBJECT (stockdata->leftButton),
+		g_signal_connect (GTK_OBJECT (stockdata->leftButton),
 					"clicked",
 					GTK_SIGNAL_FUNC(zipLeft),stockdata);
-		gtk_signal_connect (GTK_OBJECT (stockdata->rightButton),
+		g_signal_connect (GTK_OBJECT (stockdata->rightButton),
 					"clicked",
 					GTK_SIGNAL_FUNC(zipRight),stockdata);
 		g_signal_connect (G_OBJECT (stockdata->leftButton), 
@@ -1798,25 +1836,25 @@ static gint updateOutput(gpointer data)
 
 		gtk_container_add (GTK_CONTAINER (applet), vbox);
 
-		gtk_signal_connect(GTK_OBJECT(stockdata->drawing_area),"expose_event",
-		(GtkSignalFunc) expose_event, stockdata);
+		g_signal_connect(GTK_OBJECT(stockdata->drawing_area),"expose_event",
+				 (GtkSignalFunc) expose_event, stockdata);
 
-		gtk_signal_connect(GTK_OBJECT(stockdata->drawing_area),"configure_event",
-		(GtkSignalFunc) configure_event, stockdata);
+		g_signal_connect(GTK_OBJECT(stockdata->drawing_area),"configure_event",
+				 (GtkSignalFunc) configure_event, stockdata);
 
 
 		/* CLEAN UP WHEN REMOVED FROM THE PANEL */
-		gtk_signal_connect(GTK_OBJECT(applet), "destroy",
-			GTK_SIGNAL_FUNC(destroy_applet), stockdata);
+		g_signal_connect(GTK_OBJECT(applet), "destroy",
+				 GTK_SIGNAL_FUNC(destroy_applet), stockdata);
 
 		g_signal_connect (G_OBJECT (applet), "change_size",
 				  G_CALLBACK (applet_change_size), stockdata);
 				  
 		g_signal_connect (G_OBJECT (applet), "style_set",
-					   G_CALLBACK (style_set_cb), stockdata);
+				  G_CALLBACK (style_set_cb), stockdata);
 					   
 		g_signal_connect (applet, "key_press_event",
-					  G_CALLBACK (key_press_cb), stockdata);
+				  G_CALLBACK (key_press_cb), stockdata);
 
 		gtk_widget_show (GTK_WIDGET (applet));
 		
@@ -1869,8 +1907,6 @@ static gint updateOutput(gpointer data)
 	{
 		gboolean retval = FALSE;
     
-		setup_factory();
-    
 		if (!strcmp (iid, "OAFIID:GNOME_GtikApplet"))
 			retval = gtik_applet_fill (applet); 
     
@@ -1933,8 +1969,8 @@ static gint updateOutput(gpointer data)
 
 	/*-----------------------------------------------------------------*/
 	char *splitPrice(char *data) {
-		char buff[128]="";
-		static char buff2[128]="";
+		char buff[MAX_SYMBOL_LEN]="";
+		static char buff2[MAX_SYMBOL_LEN]="";
 		char *var1, *var2;
 
 		strcpy(buff,data);
@@ -1951,13 +1987,13 @@ static gint updateOutput(gpointer data)
 
 	/*-----------------------------------------------------------------*/
 	char *splitChange(StockData *stockdata,char *data, StockQuote *quote) {
-		char buff[128]; 
-		static char buff2[128];
+		char buff[MAX_SYMBOL_LEN]; 
+		static char buff2[MAX_SYMBOL_LEN];
 		char *var1, *var2, *var3, *var4;
 		char rise[2]; 
 
-                bzero(buff, 128); 
-                bzero(buff2, 128); 
+                bzero(buff, MAX_SYMBOL_LEN); 
+                bzero(buff2, MAX_SYMBOL_LEN); 
                 bzero(rise, 2); 
                 
 		strcpy(buff,data);
@@ -1987,8 +2023,11 @@ static gint updateOutput(gpointer data)
 			quote->color = RED;
 		}
 		else {
-			var3 = g_strdup(_("(No"));
-			var4 = g_strdup(_("Change "));
+			/* TRANSLATOR: This forms part of a sentance
+			 * "(No Change)". FIXME: string composition is bad.
+			 */
+			var3 = g_strdup(_("(No Change"));
+			var4 = g_strdup("");
 			quote->color = WHITE;
 		}
 
